==> codacy-plugins_2.12-8.5.7_play_2.7.jar: tool-cache/codacy-sonar-csharp/docs/description/S4057.md <==

When you create a `DataTable` or `DataSet`, you should set the locale explicitly. By default, the locale for these types is<br>the current culture. For data that is stored in a database or file and is shared globally, the locale should ordinarily be set to the invariant<br>culture (`CultureInfo.InvariantCulture`).

This rule raises an issue when `System.Data.DataTable` or `System.Data.DataSet` instances are created without explicitly<br>setting the locale property (`DataTable.Locale` or `DataSet.Locale`).

## Noncompliant Code Example


    using System;
    using System.Data;
    
    namespace MyLibrary
    {
        public class Foo
        {
            public DataTable CreateTable()
            {
                DataTable table = new DataTable("Customers"); // Noncompliant table.Locale not set
                DataColumn key = table.Columns.Add("ID", typeof(Int32));
    
                key.AllowDBNull = false;
                key.Unique = true;
                table.Columns.Add("LastName", typeof(String));
                table.Columns.Add("FirstName", typeof(String));
                return table;
            }
        }
    }


## Compliant Solution


    using System;
    using System.Data;
    using System.Globalization;
    
    namespace MyLibrary
    {
        public class Foo
        {
            public DataTable CreateTable()
            {
                DataTable table = new DataTable("Customers");
                table.Locale = CultureInfo.InvariantCulture;
                DataColumn key = table.Columns.Add("ID", typeof(Int32));
    
                key.AllowDBNull = false;
                key.Unique = true;
                table.Columns.Add("LastName", typeof(String));
                table.Columns.Add("FirstName", typeof(String));
                return table;
            }
        }
    }

==> codacy-plugins_2.12-11.0.1_play_2.6.jar: tool-cache/codacy-sonar-csharp/docs/description/S4057.md <==

When you create a `DataTable` or `DataSet`, you should set the locale explicitly. By default, the locale for these types is the current culture. For data that is stored in a database or file and is shared globally, the locale should ordinarily be set to the invariant culture (`CultureInfo.InvariantCulture`).

This rule raises an issue when `System.Data.DataTable` or `System.Data.DataSet` instances are created without explicitly setting the locale property (`DataTable.Locale` or `DataSet.Locale`).

## Noncompliant Code Example


    using System;
    using System.Data;
    
    namespace MyLibrary
    {
        public class Foo
        {
            public DataTable CreateTable()
            {
                DataTable table = new DataTable("Customers"); // Noncompliant table.Locale not set
                DataColumn key = table.Columns.Add("ID", typeof(Int32));
    
                key.AllowDBNull = false;
                key.Unique = true;
                table.Columns.Add("LastName", typeof(String));
                table.Columns.Add("FirstName", typeof(String));
                return table;
            }
        }
    }


## Compliant Solution


    using System;
    using System.Data;
    using System.Globalization;
    
    namespace MyLibrary
    {
        public class Foo
        {
            public DataTable CreateTable()
            {
                DataTable table = new DataTable("Customers");
                table.Locale = CultureInfo.InvariantCulture;
                DataColumn key = table.Columns.Add("ID", typeof(Int32));
    
                key.AllowDBNull = false;
                key.Unique = true;
                table.Columns.Add("LastName", typeof(String));
                table.Columns.Add("FirstName", typeof(String));
                return table;
            }
        }
    }
